searchData={"items":[{"type":"module","title":"ErrorTracker","doc":"En Elixir-based built-in error tracking solution.\n\nThe main objectives behind this project are:\n\n* Provide a basic free error tracking solution: because tracking errors in\nyour application should be a requirement for almost any project, and helps to\nprovide quality and maintenance to your project.\n\n* Be easy to use: by providing plug-and-play integrations, documentation and a\nsimple UI to manage your errors.\n\n* Be as minimalistic as possible: you just need a database to store errors and\na Phoenix application if you want to inspect them via web. That's all.","ref":"ErrorTracker.html"},{"type":"module","title":"Requirements - ErrorTracker","doc":"ErrorTracker requires Elixir 1.15+, Ecto 3.11+, Phoenix LiveView 0.19+, and PostgreSQL.","ref":"ErrorTracker.html#module-requirements"},{"type":"module","title":"Integrations - ErrorTracker","doc":"We currently include integrations for what we consider the basic stack of\nan application: Phoenix, Plug, and Oban.\n\nHowever, we may continue working in adding support for more systems and\nlibraries in the future if there is enough interest from the community.\n\nIf you want to manually report an error, you can use the `ErrorTracker.report/3` function.","ref":"ErrorTracker.html#module-integrations"},{"type":"module","title":"Context - ErrorTracker","doc":"Aside from the information about each exception (kind, message, stack trace...)\nwe also store contexts.\n\nContexts are arbitrary maps that allow you to store extra information about an\nexception to be able to reproduce it later.\n\nEach integration includes a default context with useful information they\ncan gather, but aside from that, you can also add your own information. You can\ndo this in a per-process basis or in a per-call basis (or both).\n\n**Per process**\n\nThis allows you to set a general context for the current process such as a Phoenix\nrequest or an Oban job. For example, you could include the following code in your\nauthentication Plug to automatically include the user ID in any error that is\ntracked during the Phoenix request handling.\n\n```elixir\nErrorTracker.set_context(%{user_id: conn.assigns.current_user.id})\n```\n\n**Per call**\n\nAs we had seen before, you can use `ErrorTracker.report/3` to manually report an\nerror. The third parameter of this function is optional and allows you to include\nextra context that will be tracked along with the error.","ref":"ErrorTracker.html#module-context"},{"type":"function","title":"ErrorTracker.get_context/0","doc":"Obtain the context of the current process.","ref":"ErrorTracker.html#get_context/0"},{"type":"function","title":"ErrorTracker.report/3","doc":"Report an exception to be stored.\n\nAside from the exception, it is expected to receive the stack trace and,\noptionally, a context map which will be merged with the current process\ncontext.\n\nKeep in mind that errors that occur in Phoenix controllers, Phoenix LiveViews\nand Oban jobs are automatically reported. You will need this function only if you\nwant to report custom errors.\n\n```elixir\ntry do\n  # your code\ncatch\n  e ->\n    ErrorTracker.report(e, __STACKTRACE__)\nend\n```","ref":"ErrorTracker.html#report/3"},{"type":"function","title":"Exceptions - ErrorTracker.report/3","doc":"Exceptions can be passed in three different forms:\n\n* An exception struct: the module of the exception is stored along with\nthe exception message.\n\n* A `{kind, exception}` tuple in which the `exception` is a struct: it\nbehaves the same as when passing just the exception struct.\n\n* A `{kind, reason}` tuple: it stores the kind and the message itself cast\nto strings, which is useful for some errors like EXIT signals or custom error\nmessages.","ref":"ErrorTracker.html#report/3-exceptions"},{"type":"function","title":"ErrorTracker.resolve/1","doc":"Marks an error as resolved.\n\nIf an error is marked as resolved and it happens again, it will automatically\nappear as unresolved again.","ref":"ErrorTracker.html#resolve/1"},{"type":"function","title":"ErrorTracker.set_context/1","doc":"Sets the current process context.\n\nThe given context will be merged into the current process context. The given context\nmay override existing keys from the current process context.","ref":"ErrorTracker.html#set_context/1"},{"type":"function","title":"Context depth - ErrorTracker.set_context/1","doc":"You can store context on more than one level of depth, but take into account\nthat the merge operation is performed on the first level.\n\nThat means that any existing data on deep levels for he current context will\nbe replaced if the first level key is received on the new contents.","ref":"ErrorTracker.html#set_context/1-context-depth"},{"type":"function","title":"ErrorTracker.unresolve/1","doc":"Marks an error as unresolved.","ref":"ErrorTracker.html#unresolve/1"},{"type":"type","title":"ErrorTracker.context/0","doc":"A map containing the relevant context for a particular error.","ref":"ErrorTracker.html#t:context/0"},{"type":"behaviour","title":"ErrorTracker.Migration","doc":"Create and modify the database tables for ErrorTracker.","ref":"ErrorTracker.Migration.html"},{"type":"behaviour","title":"Usage - ErrorTracker.Migration","doc":"To use ErrorTracker migrations in your application you will need to generate\na regular `Ecto.Migration` that performs the relevant calls to `ErrorTracker.Migration`.\n\n```bash\nmix ecto.gen.migration add_error_tracker\n```\n\nOpen the generated migration file and call the `up` and `down` functions on\n`ErrorTracker.Migration`.\n\n```elixir\ndefmodule MyApp.Repo.Migrations.AddErrorTracker do\n  use Ecto.Migration\n\n  def up, do: ErrorTracker.Migration.up()\n  def down, do: ErrorTracker.Migration.down()\nend\n```\n\nThis will run every ErrorTracker migration for your database. You can now run the migration\nand perform the database changes:\n\n```bash\nmix ecto.migrate\n```\n\nAs new versions of ErrorTracker are released you may need to run additional migrations.\nTo do this you can follow the previous process and create a new migration:\n\n```bash\nmix ecto.gen.migration update_error_tracker_to_vN\n```\n\nOpen the generated migration file and call the `up` and `down` functions on the\n`ErrorTracker.Migration` passing the desired `version`.\n\n```elixir\ndefmodule MyApp.Repo.Migrations.UpdateErrorTrackerToVN do\n  use Ecto.Migration\n\n  def up, do: ErrorTracker.Migration.up(version: N)\n  def down, do: ErrorTracker.Migration.down(version: N)\nend\n```\n\nThen run the migrations to perform the database changes:\n\n```bash\nmix ecto.migrate\n```","ref":"ErrorTracker.Migration.html#module-usage"},{"type":"behaviour","title":"Custom prefix - ErrorTracker.Migration","doc":"ErrorTracker supports namespacing its own tables using PostgreSQL schemas, also known\nas \"prefixes\" in Ecto. With prefixes your error tables can reside outside of your primary\nschema (which is usually named \"public\").\n\nTo use a prefix you need to specify it in your migrations:\n\n```elixir\ndefmodule MyApp.Repo.Migrations.AddErrorTracker do\n  use Ecto.Migration\n\n  def up, do: ErrorTracker.Migration.up(prefix: \"custom_schema\")\n  def down, do: ErrorTracker.Migration.down(prefix: \"custom_schema\")\nend\n```\n\nThis will automatically create the database schema for you. If the schema does already exist\nthe migration may fail when trying to recreate it. In such cases you can instruct ErrorTracker\nnot to create the schema again:\n\n```elixir\ndefmodule MyApp.Repo.Migrations.AddErrorTracker do\n  use Ecto.Migration\n\n  def up, do: ErrorTracker.Migration.up(prefix: \"custom_schema\", create_schema: false)\n  def down, do: ErrorTracker.Migration.down(prefix: \"custom_schema\")\nend\n```\n\nIf you are using a custom schema other than the default \"public\" you need to configure\nErrorTracker to use that schema:\n\n```elixir\nconfig :error_tracker, :prefix, \"custom_schema\"\n```","ref":"ErrorTracker.Migration.html#module-custom-prefix"},{"type":"callback","title":"ErrorTracker.Migration.current_version/1","doc":"","ref":"ErrorTracker.Migration.html#c:current_version/1"},{"type":"function","title":"ErrorTracker.Migration.down/1","doc":"","ref":"ErrorTracker.Migration.html#down/1"},{"type":"callback","title":"ErrorTracker.Migration.down/1","doc":"","ref":"ErrorTracker.Migration.html#c:down/1"},{"type":"function","title":"ErrorTracker.Migration.migrated_version/1","doc":"","ref":"ErrorTracker.Migration.html#migrated_version/1"},{"type":"function","title":"ErrorTracker.Migration.up/1","doc":"","ref":"ErrorTracker.Migration.html#up/1"},{"type":"callback","title":"ErrorTracker.Migration.up/1","doc":"","ref":"ErrorTracker.Migration.html#c:up/1"},{"type":"module","title":"ErrorTracker.Integrations.Oban","doc":"Integration with Oban.","ref":"ErrorTracker.Integrations.Oban.html"},{"type":"module","title":"How to use it - ErrorTracker.Integrations.Oban","doc":"It is a plug and play integration: as long as you have Oban installed the\nErrorTracker will receive and store the errors as they are reported.","ref":"ErrorTracker.Integrations.Oban.html#module-how-to-use-it"},{"type":"module","title":"How it works - ErrorTracker.Integrations.Oban","doc":"It works using Oban's Telemetry events, so you don't need to modify anything\non your application.","ref":"ErrorTracker.Integrations.Oban.html#module-how-it-works"},{"type":"module","title":"Default context - ErrorTracker.Integrations.Oban","doc":"By default we store some context for you on errors generated in an Oban\nprocess:\n\n* `job.id`: the unique ID of the job.\n\n* `job.worker`: the name of the worker module.\n\n* `job.queue`: the name of the queue in which the job was inserted.\n\n* `job.args`: the arguments of the job being executed.\n\n* `job.priority`: the priority of the job.\n\n* `job.attempt`: the number of attempts performed for the job.","ref":"ErrorTracker.Integrations.Oban.html#module-default-context"},{"type":"function","title":"ErrorTracker.Integrations.Oban.attach/0","doc":"Attaches to Oban's Telemetry events if the library is detected.\n\nThis function is usually called internally during the startup process so you\ndon't have to.","ref":"ErrorTracker.Integrations.Oban.html#attach/0"},{"type":"module","title":"ErrorTracker.Integrations.Phoenix","doc":"Integration with Phoenix applications.","ref":"ErrorTracker.Integrations.Phoenix.html"},{"type":"module","title":"How to use it - ErrorTracker.Integrations.Phoenix","doc":"It is a plug and play integration: as long as you have Phoenix installed the\nErrorTracker will receive and store the errors as they are reported.\n\nIt also collects the exceptions that raise on your LiveView modules.","ref":"ErrorTracker.Integrations.Phoenix.html#module-how-to-use-it"},{"type":"module","title":"How it works - ErrorTracker.Integrations.Phoenix","doc":"It works using Phoenix's Telemetry events, so you don't need to modify\nanything on your application.","ref":"ErrorTracker.Integrations.Phoenix.html#module-how-it-works"},{"type":"module","title":"Errors on the Endpoint - ErrorTracker.Integrations.Phoenix","doc":"This integration only catches errors that raise after the requests hits your\nRouter. That means that an exception on a plug defined on your Endpoint will\nnot be reported.\n\nIf you want to also catch those errors, we recommend you to set up the\n`ErrorTracker.Integrations.Plug` integration too.","ref":"ErrorTracker.Integrations.Phoenix.html#module-errors-on-the-endpoint"},{"type":"module","title":"Default context - ErrorTracker.Integrations.Phoenix","doc":"For errors that are reported when executing regular HTTP requests (the ones\nthat go to Controllers), the context added by default is the same that you\ncan find on the `ErrorTracker.Integrations.Plug` integration.\n\nAs for exceptions generated in LiveView processes, we collect some special\ninformation on the context:\n\n* `live_view.view`: the LiveView module itself,\n\n* `live_view.uri`: last URI that loaded the LiveView (available when the\n`handle_params` function is invoked).\n\n* `live_view.params`: the params received by the LiveView (available when the\n`handle_params` function is invoked).\n\n* `live_view.event`: last event received by the LiveView (available when the\n`handle_event` function is invoked).\n\n* `live_view.event_params`: last event params received by the LiveView\n(available when the `handle_event` function is invoked).","ref":"ErrorTracker.Integrations.Phoenix.html#module-default-context"},{"type":"function","title":"ErrorTracker.Integrations.Phoenix.attach/0","doc":"Attaches to Phoenix's Telemetry events if the library is detected.\n\nThis function is usually called internally during the startup process so you\ndon't have to.","ref":"ErrorTracker.Integrations.Phoenix.html#attach/0"},{"type":"module","title":"ErrorTracker.Integrations.Plug","doc":"Integration with Plug applications.","ref":"ErrorTracker.Integrations.Plug.html"},{"type":"module","title":"How to use it - ErrorTracker.Integrations.Plug","doc":"","ref":"ErrorTracker.Integrations.Plug.html#module-how-to-use-it"},{"type":"module","title":"Plug applications - ErrorTracker.Integrations.Plug","doc":"The way to use this integration is by adding it to either your `Plug.Builder`\nor `Plug.Router`:\n\n```elixir\ndefmodule MyApp.Router do\n  use Plug.Router\n  use ErrorTracker.Integrations.Plug\n\n  ...\nend\n```","ref":"ErrorTracker.Integrations.Plug.html#module-plug-applications"},{"type":"module","title":"Phoenix applications - ErrorTracker.Integrations.Plug","doc":"There is a particular use case which can be useful when running a Phoenix\nweb application.\n\nIf you want to record exceptions that may occur in your application's endpoint\nbefore reaching your router (for example, in any plug like the ones decoding\ncookies of body contents) you may want to add this integration too:\n\n```elixir\ndefmodule MyApp.Endpoint do\n  use Phoenix.Endpoint\n  use ErrorTracker.Integrations.Plug\n\n  ...\nend\n```","ref":"ErrorTracker.Integrations.Plug.html#module-phoenix-applications"},{"type":"module","title":"Default context - ErrorTracker.Integrations.Plug","doc":"By default we store some context for you on errors generated during a Plug\nrequest:\n\n* `request.host`: the `conn.host` value.\n\n* `request.ip`: the IP address that initiated the request. It includes parsing\nproxy headers\n\n* `request.method`: the HTTP method of the request.\n\n* `request.path`: the path of the request.\n\n* `request.query`: the query string of the request.\n\n* `request.params`: parsed params of the request (only available if they have\nbeen fetched and parsed as part of the Plug pipeline).\n\n* `request.headers`: headers received on the request. All headers are included\nby default except for the `Cookie` ones, as they may include large and\nsensitive content like sessions.","ref":"ErrorTracker.Integrations.Plug.html#module-default-context"},{"type":"module","title":"ErrorTracker.Error","doc":"Schema to store an error or exception recorded by ErrorTracker.\n\nIt stores a kind, reason and source code location to generate a unique\nfingerprint that can be used to avoid duplicates.\n\nThe fingerprint currently does not include the reason itself because it can\ncontain specific details that can change on the same error depending on\nruntime conditions.","ref":"ErrorTracker.Error.html"},{"type":"module","title":"ErrorTracker.Occurrence","doc":"Schema to store a particular instance of an error in a given time.\n\nIt contains all the metadata available about the moment and the environment\nin which the exception raised.","ref":"ErrorTracker.Occurrence.html"},{"type":"module","title":"ErrorTracker.Stacktrace","doc":"An Stacktrace contains the information about the execution stack for a given\noccurrence of an exception.","ref":"ErrorTracker.Stacktrace.html"},{"type":"function","title":"ErrorTracker.Stacktrace.new/1","doc":"","ref":"ErrorTracker.Stacktrace.html#new/1"},{"type":"function","title":"ErrorTracker.Stacktrace.source/1","doc":"Source of the error stack trace.\n\nThe first line matching the client application. If no line belongs to the current\napplication, just the first line.","ref":"ErrorTracker.Stacktrace.html#source/1"},{"type":"module","title":"ErrorTracker.Stacktrace.Line","doc":"","ref":"ErrorTracker.Stacktrace.Line.html"},{"type":"module","title":"ErrorTracker.Web","doc":"ErrorTracker includes a dashboard to view and inspect errors that occurred\non your application and are already stored in the database.\n\nIn order to use it, you need to add the following to your Phoenix's\n`router.ex` file:\n\n```elixir\ndefmodule YourAppWeb.Router do\n  use Phoenix.Router\n  use ErrorTracker.Web, :router\n\n  ...\n\n  error_tracker_dashboard \"/errors\"\nend\n```\n\nThis will add the routes needed for ErrorTracker's dashboard to work.","ref":"ErrorTracker.Web.html"},{"type":"module","title":"Security considerations - ErrorTracker.Web","doc":"Errors may contain sensitive information, like IP addresses, users information\nor even passwords sent on forms!\n\nSecuring your dashboard is an important part of integrating ErrorTracker on\nyour project.\n\nIn order to do so, we recommend implementing your own security mechanisms in\nthe form of a mount hook and pass it to the `error_tracker_dashboard` macro\nusing the `on_mount` option.\n\nYou can find more details on\n`ErrorTracker.Web.Router.error_tracker_dashboard/2`.","ref":"ErrorTracker.Web.html#module-security-considerations"},{"type":"module","title":"LiveView socket options - ErrorTracker.Web","doc":"By default the library expects you to have your LiveView socket at `/live` and\nusing `websocket` transport.\n\nIf that's not the case, you can configure it adding the following\nconfiguration to your app's config files:\n\n```elixir\nconfig :error_tracker,\n  socket: [\n    path: \"/my-custom-socket-path\"\n    transport: :longpoll # (accepted values are :longpoll or :websocket)\n  ]\n```","ref":"ErrorTracker.Web.html#module-liveview-socket-options"},{"type":"module","title":"ErrorTracker.Web.Router","doc":"ErrorTracker UI integration into your application's router.","ref":"ErrorTracker.Web.Router.html"},{"type":"macro","title":"ErrorTracker.Web.Router.error_tracker_dashboard/2","doc":"Creates the routes needed to use the `ErrorTracker` web interface.\n\nIt requires a path in which you are going to serve the web interface.","ref":"ErrorTracker.Web.Router.html#error_tracker_dashboard/2"},{"type":"macro","title":"Security considerations - ErrorTracker.Web.Router.error_tracker_dashboard/2","doc":"Errors may contain sensitive information so it is recommended to use the `on_mount`\noption to provide a custom hook that implements authentication and authorization\nfor access control.","ref":"ErrorTracker.Web.Router.html#error_tracker_dashboard/2-security-considerations"},{"type":"macro","title":"Options - ErrorTracker.Web.Router.error_tracker_dashboard/2","doc":"* `on_mount`: a list of mount hooks to use before invoking the dashboard\nLiveView views.\n\n* `as`: a session name to use for the dashboard LiveView session. By default\nit uses `:error_tracker_dashboard`.","ref":"ErrorTracker.Web.Router.html#error_tracker_dashboard/2-options"},{"type":"extras","title":"Getting Started","doc":"# Getting Started\n\nThis guide is an introduction to ErrorTracker, an Elixir-based built-in error tracking solution. ErrorTracker provides a basic and free error-tracking solution integrated in your own application. It is designed to be easy to install and easy to use so you can integrate it in your existing project with minimal changes. The only requirement is a relational database in which errors will be tracked.\n\nIn this guide we will learn how to install ErrorTracker in an Elixir project so you can start reporting errors as soon as possible. We will also cover more advanced topics such as how to report custom errors and how to add extra context to reported errors.\n\n**This guide requires you to have set up Ecto with PostgreSQL beforehand.**","ref":"getting-started.html"},{"type":"extras","title":"Installing the ErrorTracker as a dependency - Getting Started","doc":"The first step to add ErrorTracker to your application is to declare the package as a dependency in your `mix.exs` file:\n\n```elixir\n# mix.exs\ndefp deps do\n  [\n    {:error_tracker, \"~> 0.1\"}\n  ]\nend\n```\n\nOnce ErrorTracker is declared as a dependency of your application, you can install it with the following command:\n\n```bash\nmix deps.get\n```","ref":"getting-started.html#installing-the-errortracker-as-a-dependency"},{"type":"extras","title":"Configuring ErrorTracker - Getting Started","doc":"ErrorTracker needs a few configuration options to work. This configuration should be added to your `config/config.exs` file:\n\n```elixir\nconfig :error_tracker,\n  repo: MyApp.Repo,\n  otp_app: :my_app\n```\n\nThe `:repo` option specifies the repository that will be used by ErrorTracker. You can use your regular application repository or a different one if you prefer to keep errors in a different database.\n\nThe `:otp_app` option specifies your application name. When an error occurs, ErrorTracker will use this information to understand which parts of the stack trace belong to your application and which parts belong to third-party dependencies. This allows you to filter in-app vs third-party frames when viewing errors.","ref":"getting-started.html#configuring-errortracker"},{"type":"extras","title":"Setting up the database - Getting Started","doc":"Since ErrorTracker stores errors in the database you must create a database migration to add the required tables:\n\n```\nmix ecto.gen.migration add_error_tracker\n```\n\nOpen the generated migration and call the `up` and `down` functions on `ErrorTracker.Migration`:\n\n```elixir\ndefmodule MyApp.Repo.Migrations.AddErrorTracker do\n  use Ecto.Migration\n\n  def up, do: ErrorTracker.Migration.up()\n  def down, do: ErrorTracker.Migration.down()\nend\n```\n\nYou can run the migration and apply the database changes with the following command:\n\n```bash\nmix ecto.migrate\n```\n\nFor more information about how to handle migrations, take a look at the `ErrorTracker.Migration` module docs.","ref":"getting-started.html#setting-up-the-database"},{"type":"extras","title":"Automatic error tracking - Getting Started","doc":"At this point, ErrorTracker is ready to track errors. It will automatically start when your application boots and track errors that occur in your Phoenix controllers, Phoenix LiveViews and Oban jobs. The `ErrorTracker.Integrations.Phoenix` and `ErrorTracker.Integrations.Oban` provide detailed information about how this works.\n\nIf your application uses Plug but not Phoenix, you will need to add the relevant integration in your `Plug.Builder` or `Plug.Router` module.\n\n```elixir\ndefmodule MyApp.Router do\n  use Plug.Router\n  use ErrorTracker.Integrations.Plug\n\n  # Your code here\nend\n```\n\nThis is also required if you want to track errors that happen in your Phoenix endpoint, before the Phoenix router starts handling the request. Keep in mind that this won't be needed in most cases as endpoint errors are infrequent.\n\n```elixir\ndefmodule MyApp.Endpoint do\n  use Phoenix.Endpoint\n  use ErrorTracker.Integrations.Plug\n\n  # Your code here\nend\n```\n\nYou can learn more about this in the `ErrorTracker.Integrations.Plug` module documentation.","ref":"getting-started.html#automatic-error-tracking"},{"type":"extras","title":"Error context - Getting Started","doc":"The default integrations include some additional context when tracking errors. You can take a look at the relevant integration modules to see what is being tracked out of the box.\n\nIn certain cases, you may want to include some additional information when tracking errors. For example it may be useful to track the user ID that was using the application when an error happened. Fortunately, ErrorTracker allows you to enrich the default context with custom information.\n\nThe `ErrorTracker.set_context/1` function stores the given context in the current process so any errors that occur in that process (for example, a Phoenix request or an Oban job) will include this given context along with the default integration context.\n\n```elixir\nErrorTracker.set_context(%{user_id: conn.assigns.current_user.id})\n```","ref":"getting-started.html#error-context"},{"type":"extras","title":"Manual error tracking - Getting Started","doc":"If you want to report custom errors that fall outside the default integration scope, you may use `ErrorTracker.report/2`. This allows you to report an exception yourself:\n\n```elixir\ntry do\n  # your code\ncatch\n  e ->\n    ErrorTracker.report(e, __STACKTRACE__)\nend\n```\n\nYou can also use `ErrorTracker.report/3` and set some custom context that will be included along with the reported error.","ref":"getting-started.html#manual-error-tracking"},{"type":"extras","title":"Web UI - Getting Started","doc":"ErrorTracker also provides a dashboard built with Phoenix LiveView that can be used to see and manage the recorded errors.\n\nThis is completely optional, and you can find more information about it in the `ErrorTracker.Web` module documentation.","ref":"getting-started.html#web-ui"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,51,46,48]}}